@@ -154,7 +154,7 @@ void framedraw_add_label(GtkVBox *box) {
 
   // TRANSLATORS - Preview refers to preview window; keep this phrase short
   label=lives_standard_label_new(_("You can click in Preview to change these values"));
-  lives_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (box), label, FALSE, FALSE, 0);
 }
 
 
@@ -165,11 +165,11 @@ void framedraw_add_reset(GtkVBox *box, lives_special_framedraw_rect_t *framedraw
 
   mainw->framedraw_reset = gtk_button_new_from_stock ("gtk-refresh");
   hbox_rst = lives_hbox_new (FALSE, 0);
-  lives_box_pack_start (GTK_BOX (box), hbox_rst, FALSE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (box), hbox_rst, FALSE, FALSE, 0);
   
   lives_button_set_label (GTK_BUTTON (mainw->framedraw_reset),_ ("_Reset Values"));
   gtk_button_set_use_underline (GTK_BUTTON (mainw->framedraw_reset), TRUE);
-  lives_box_pack_start (GTK_BOX (hbox_rst), mainw->framedraw_reset, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (hbox_rst), mainw->framedraw_reset, TRUE, FALSE, 0);
   lives_widget_set_sensitive (mainw->framedraw_reset,FALSE);
   
   g_signal_connect (mainw->framedraw_reset, "clicked",G_CALLBACK (on_framedraw_reset_clicked),framedraw);
@@ -204,28 +204,28 @@ void widget_add_framedraw (GtkVBox *box, int start, int end, boolean add_preview
   mainw->framedraw_reset=NULL;
 
   vseparator = lives_vseparator_new ();
-  lives_box_pack_start (GTK_BOX (lives_widget_get_parent(LIVES_WIDGET (box))), vseparator, FALSE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (lives_widget_get_parent(LIVES_WIDGET (box))), vseparator, FALSE, FALSE, 0);
   lives_widget_show (vseparator);
 
   vbox = lives_vbox_new (FALSE, 0);
-  lives_box_pack_start (GTK_BOX (lives_widget_get_parent(LIVES_WIDGET (box))), vbox, FALSE, FALSE, 0);
-  lives_container_set_border_width (GTK_CONTAINER (vbox), widget_opts.border_width);
+  lives_box_pack_start (LIVES_BOX (lives_widget_get_parent(LIVES_WIDGET (box))), vbox, FALSE, FALSE, 0);
+  lives_container_set_border_width (LIVES_CONTAINER (vbox), widget_opts.border_width);
 
   fd_scale=calc_fd_scale(width,height);
   width/=fd_scale;
   height/=fd_scale;
  
   hbox = lives_hbox_new (FALSE, 0);
-  lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  add_fill_to_box(GTK_BOX(hbox));
+  lives_box_pack_start (LIVES_BOX (vbox), hbox, FALSE, FALSE, 0);
+  add_fill_to_box(LIVES_BOX(hbox));
 
-  fbord_eventbox=gtk_event_box_new();
-  lives_container_set_border_width(GTK_CONTAINER(fbord_eventbox),widget_opts.border_width);
+  fbord_eventbox=lives_event_box_new();
+  lives_container_set_border_width(LIVES_CONTAINER(fbord_eventbox),widget_opts.border_width);
 
   frame = gtk_frame_new (NULL);
 
-  add_fill_to_box(GTK_BOX(hbox));
-  lives_box_pack_start (GTK_BOX (hbox), frame, FALSE, FALSE, 0);
+  add_fill_to_box(LIVES_BOX(hbox));
+  lives_box_pack_start (LIVES_BOX (hbox), frame, FALSE, FALSE, 0);
 
   if (palette->style&STYLE_1) {
     lives_widget_set_bg_color (fbord_eventbox, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
@@ -238,19 +238,19 @@ void widget_add_framedraw (GtkVBox *box, int start, int end, boolean add_preview
   label = lives_standard_label_new (_("Preview"));
   gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 
-  gtk_frame_set_shadow_type (GTK_FRAME(frame), GTK_SHADOW_NONE);
+  gtk_frame_set_shadow_type (GTK_FRAME(frame), LIVES_SHADOW_NONE);
 
-  mainw->framedraw=gtk_event_box_new();
+  mainw->framedraw=lives_event_box_new();
   lives_widget_set_size_request (mainw->framedraw, width, height);
-  lives_container_set_border_width(GTK_CONTAINER(mainw->framedraw),1);
+  lives_container_set_border_width(LIVES_CONTAINER(mainw->framedraw),1);
 
   gtk_widget_set_events (mainw->framedraw, GDK_BUTTON1_MOTION_MASK | GDK_BUTTON_RELEASE_MASK | 
 			 GDK_BUTTON_PRESS_MASK| GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
 
   mainw->framedraw_frame=start;
 
-  lives_container_add (GTK_CONTAINER (frame), fbord_eventbox);
-  lives_container_add (GTK_CONTAINER (fbord_eventbox), mainw->framedraw);
+  lives_container_add (LIVES_CONTAINER (frame), fbord_eventbox);
+  lives_container_add (LIVES_CONTAINER (fbord_eventbox), mainw->framedraw);
 
   if (palette->style&STYLE_1) {
     lives_widget_set_bg_color (mainw->framedraw, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
@@ -262,7 +262,7 @@ void widget_add_framedraw (GtkVBox *box, int start, int end, boolean add_preview
 
 
   hbox = lives_hbox_new (FALSE, 2);
-  lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   mainw->framedraw_spinbutton = lives_standard_spin_button_new (_("_Frame"),
 								TRUE,start,start,end,1.,10.,0,LIVES_BOX(hbox),NULL);
@@ -270,14 +270,14 @@ void widget_add_framedraw (GtkVBox *box, int start, int end, boolean add_preview
   spinbutton_adj=gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(mainw->framedraw_spinbutton));
 
   mainw->framedraw_scale=lives_hscale_new(LIVES_ADJUSTMENT(spinbutton_adj));
-  lives_box_pack_start (GTK_BOX (hbox), mainw->framedraw_scale, TRUE, TRUE, 0);
+  lives_box_pack_start (LIVES_BOX (hbox), mainw->framedraw_scale, TRUE, TRUE, 0);
   gtk_scale_set_draw_value(GTK_SCALE(mainw->framedraw_scale),FALSE);
 
   rfx=(lives_rfx_t *)g_object_get_data(G_OBJECT(lives_widget_get_toplevel(GTK_WIDGET(box))),"rfx");
   mainw->framedraw_preview = gtk_button_new_from_stock ("gtk-refresh");
   lives_button_set_label (GTK_BUTTON (mainw->framedraw_preview),_ ("_Preview"));
   gtk_button_set_use_underline (GTK_BUTTON (mainw->framedraw_preview), TRUE);
-  lives_box_pack_start (GTK_BOX (hbox), mainw->framedraw_preview, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (hbox), mainw->framedraw_preview, TRUE, FALSE, 0);
   lives_widget_set_sensitive(mainw->framedraw_spinbutton,FALSE);
   lives_widget_set_sensitive(mainw->framedraw_scale,FALSE);
   g_signal_connect (mainw->framedraw_preview, "clicked",G_CALLBACK (start_preview),rfx);
