@@ -17,13 +17,13 @@ void on_camgrab_clicked (GtkButton *button, gpointer user_data) {
   if (dvgrabw->filename!=NULL) g_free(dvgrabw->filename);
   dvgrabw->filename=find_free_camfile(cam->format);
   if (dvgrabw->filename==NULL) return;
-  gtk_widget_set_sensitive(dvgrabw->grab,FALSE);
+  lives_widget_set_sensitive(dvgrabw->grab,FALSE);
   lives_set_cursor_style(LIVES_CURSOR_BUSY,dvgrabw->dialog);
   if (!dvgrabw->playing) on_camplay_clicked(NULL,user_data);
   msg=g_strdup_printf(_("Recording to %s/%s"),dvgrabw->dirname,dvgrabw->filename);
-  gtk_entry_set_text(GTK_ENTRY(dvgrabw->status_entry),msg);
+  lives_entry_set_text(GTK_ENTRY(dvgrabw->status_entry),msg);
   if (cam->format==CAM_FORMAT_DV) {
-    dvgrabw->filename=g_strdup(gtk_entry_get_text(GTK_ENTRY(dvgrabw->filent)));
+    dvgrabw->filename=g_strdup(lives_entry_get_text(GTK_ENTRY(dvgrabw->filent)));
   }
   rec(cam);
   cam->grabbed_clips=TRUE;
@@ -32,7 +32,7 @@ void on_camgrab_clicked (GtkButton *button, gpointer user_data) {
 
 void on_camstop_clicked (GtkButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
-  gtk_widget_set_sensitive(dvgrabw->stop,FALSE);
+  lives_widget_set_sensitive(dvgrabw->stop,FALSE);
   dvgrabw->playing=FALSE;
 
   if (cam->format==CAM_FORMAT_DV) {
@@ -42,9 +42,9 @@ void on_camstop_clicked (GtkButton *button, gpointer user_data) {
 
   lives_set_cursor_style(LIVES_CURSOR_NORMAL,dvgrabw->dialog);
   camstop(cam);
-  gtk_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-play");
-  gtk_widget_set_sensitive(dvgrabw->grab,TRUE);
-  gtk_entry_set_text(GTK_ENTRY(dvgrabw->status_entry),_("Status: Ready"));
+  lives_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-play");
+  lives_widget_set_sensitive(dvgrabw->grab,TRUE);
+  lives_entry_set_text(GTK_ENTRY(dvgrabw->status_entry),_("Status: Ready"));
 }
 
 
@@ -53,25 +53,25 @@ void on_camplay_clicked (GtkButton *button, gpointer user_data) {
   camplay(cam);
   dvgrabw->playing=!dvgrabw->playing;
   if (dvgrabw->playing) {
-    gtk_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-pause");
+    lives_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-pause");
   }
   else {
-    gtk_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-play");
+    lives_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-play");
   }
-  gtk_widget_set_sensitive(dvgrabw->stop,TRUE);
+  lives_widget_set_sensitive(dvgrabw->stop,TRUE);
 }
 
 void on_camrew_clicked (GtkButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   camrew(cam);
-  gtk_widget_set_sensitive(dvgrabw->stop,TRUE);
+  lives_widget_set_sensitive(dvgrabw->stop,TRUE);
 }
 
 
 void on_camff_clicked (GtkButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   camff(cam);
-  gtk_widget_set_sensitive(dvgrabw->stop,TRUE);
+  lives_widget_set_sensitive(dvgrabw->stop,TRUE);
 }
 
 void on_cameject_clicked (GtkButton *button, gpointer user_data) {
@@ -90,7 +90,7 @@ void on_camquit_clicked (GtkButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   on_camstop_clicked(button,user_data);
   //if (cam->format==CAM_FORMAT_HDV) close_raw1394(cam->rec_handle);
-  gtk_widget_destroy(dvgrabw->dialog);
+  lives_widget_destroy(dvgrabw->dialog);
   if (dvgrabw->cursor!=NULL) lives_cursor_unref(dvgrabw->cursor);
   if (dvgrabw->filename!=NULL) g_free(dvgrabw->filename);
   if (dvgrabw->dirname!=NULL) g_free(dvgrabw->dirname);
