@@ -24,6 +24,7 @@
 #include "rte_window.h"
 #include "effects.h"
 #include "paramwindow.h"
+#include "ce_thumbs.h"
 
 static GtkWidget **key_checks;
 static GtkWidget **key_grabs;
@@ -85,7 +86,7 @@ void type_label_set_text (int key, int mode) {
 
 boolean on_clear_all_clicked (GtkButton *button, gpointer user_data) {
   int modes=rte_getmodespk();
-  int i,j;
+  register int i,j;
 
   ca_canc=FALSE;
 
@@ -109,6 +110,7 @@ boolean on_clear_all_clicked (GtkButton *button, gpointer user_data) {
 	type_label_set_text(i,j);
       }
     }
+    if (mainw->ce_thumbs) ce_thumbs_reset_combo(i);
   }
 
   if (button!=NULL) lives_widget_set_sensitive (GTK_WIDGET(button), FALSE);
@@ -1138,9 +1140,11 @@ static boolean load_datacons(const gchar *fname, uint8_t **badkeymap) {
 	    niparams=weed_leaf_num_elements(filter,"in_parameter_templates");
 	    if (ipnum>=niparams) is_valid2=FALSE;
 	    else {
-	      iparams=weed_get_plantptr_array(filter,"in_parameter_templates",&error);
-	      if (weed_plant_has_leaf(iparams[ipnum],"host_internal_connection")) is_valid2=FALSE;
-	      weed_free(iparams);
+	      if (ipnum>=0) {
+		iparams=weed_get_plantptr_array(filter,"in_parameter_templates",&error);
+		if (weed_plant_has_leaf(iparams[ipnum],"host_internal_connection")) is_valid2=FALSE;
+		weed_free(iparams);
+	      }
 	    }
 
 	    bytes=lives_read_le(kfd,&autoscale,4,TRUE);
@@ -1548,6 +1552,8 @@ boolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
   g_free(def_modes);
 
+  if (mainw->ce_thumbs) ce_thumbs_reset_combos();
+
   return FALSE;
 }
 
@@ -1603,45 +1609,45 @@ void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   lives_window_set_title (GTK_WINDOW (rte_info_window), g_strdup_printf(_("LiVES: Information for %s"),filter_name));
   lives_widget_set_bg_color(rte_info_window, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
 
-  lives_container_set_border_width (GTK_CONTAINER (rte_info_window), widget_opts.border_width);
+  lives_container_set_border_width (LIVES_CONTAINER (rte_info_window), widget_opts.border_width);
   gtk_window_set_transient_for(GTK_WINDOW(rte_info_window),GTK_WINDOW(lives_widget_get_toplevel(GTK_WIDGET(button))));
 
   gtk_window_set_default_size (GTK_WINDOW (rte_info_window), RTE_INFO_WIDTH, RTE_INFO_HEIGHT);
 
   vbox = lives_vbox_new (FALSE, widget_opts.packing_height*2);
-  lives_container_add (GTK_CONTAINER (rte_info_window), vbox);
+  lives_container_add (LIVES_CONTAINER (rte_info_window), vbox);
 
   label = lives_standard_label_new ((tmp=g_strdup_printf(_("Effect name: %s"),filter_name)));
   g_free(tmp);
-  lives_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), label, TRUE, FALSE, 0);
 
   label = lives_standard_label_new ((tmp=g_strdup_printf(_("Type: %s"),type)));
   g_free(tmp);
-  lives_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), label, TRUE, FALSE, 0);
 
   label = lives_standard_label_new ((tmp=g_strdup_printf(_("Plugin name: %s"),plugin_name)));
   g_free(tmp);
-  lives_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), label, TRUE, FALSE, 0);
 
   label = lives_standard_label_new ((tmp=g_strdup_printf(_("Author: %s"),filter_author)));
   g_free(tmp);
-  lives_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), label, TRUE, FALSE, 0);
 
   if (filter_extra_authors!=NULL) {
     label = lives_standard_label_new ((tmp=g_strdup_printf(_("and: %s"),filter_extra_authors)));
     g_free(tmp);
-    lives_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+    lives_box_pack_start (LIVES_BOX (vbox), label, TRUE, FALSE, 0);
   }
 
   label = lives_standard_label_new ((tmp=g_strdup_printf(_("Version: %d"),filter_version)));
   g_free(tmp);
-  lives_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), label, TRUE, FALSE, 0);
 
   hbox = lives_hbox_new (FALSE, widget_opts.packing_width);
-  lives_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), hbox, TRUE, FALSE, 0);
 
   label = lives_standard_label_new (_("Description: "));
-  lives_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (hbox), label, FALSE, FALSE, 0);
 
   textview = gtk_text_view_new ();
 
@@ -1655,15 +1661,15 @@ void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textview), FALSE);
   
   text_view_set_text (LIVES_TEXT_VIEW(textview), filter_description,-1);
-  lives_box_pack_start (GTK_BOX (hbox), textview, TRUE, TRUE, 0);
+  lives_box_pack_start (LIVES_BOX (hbox), textview, TRUE, TRUE, 0);
   
   hbuttonbox = lives_hbutton_box_new ();
-  lives_box_pack_start (GTK_BOX (vbox), hbuttonbox, TRUE, TRUE, 0);
+  lives_box_pack_start (LIVES_BOX (vbox), hbuttonbox, TRUE, TRUE, 0);
 
   ok_button = gtk_button_new_from_stock ("gtk-ok");
   lives_widget_show (ok_button);
 
-  lives_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
+  lives_container_add (LIVES_CONTAINER (hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default (ok_button);
   gtk_widget_grab_default (ok_button);
 
@@ -1692,7 +1698,7 @@ void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
 void on_clear_clicked (GtkButton *button, gpointer user_data) {
   // this is for the "delete" buttons, c.f. clear_all
 
-  gint idx=GPOINTER_TO_INT(user_data);
+  int idx=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   int key=(int)(idx/modes);
   int mode=idx-key*modes;
@@ -1701,19 +1707,20 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
 
   register int i;
 
+  g_print("del fx %d mode %d\n",key,mode);
   weed_delete_effectkey (key+1,mode);
 
-  pconx_delete(-1,0,0,key,mode,-1);
-  pconx_delete(key,mode,-1,-1,0,0);
+  pconx_delete(FX_DATA_WILDCARD,0,0,key,mode,FX_DATA_WILDCARD);
+  pconx_delete(key,mode,FX_DATA_WILDCARD,-1,0,0);
 
-  cconx_delete(-1,0,0,key,mode,-1);
-  cconx_delete(key,mode,-1,-1,0,0);
+  cconx_delete(FX_DATA_WILDCARD,0,0,key,mode,FX_DATA_WILDCARD);
+  cconx_delete(key,mode,FX_DATA_WILDCARD,FX_DATA_WILDCARD,0,0);
 
 
   newmode=rte_key_getmode(key+1);
-  g_signal_handler_block(mode_radios[key*modes+newmode],mode_ra_fns[key*modes+newmode]);
+
   rtew_set_mode_radio(key,newmode);
-  g_signal_handler_unblock(mode_radios[key*modes+newmode],mode_ra_fns[key*modes+newmode]);
+  if (mainw->ce_thumbs) ce_thumbs_set_mode_combo(key,newmode);
     
   for (i=mode;i<rte_getmodespk()-1;i++) {
     idx=key*modes+i;
@@ -1726,15 +1733,18 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
   lives_entry_set_text (GTK_ENTRY(combo_entries[idx]),"");
   type_label_set_text(key,i);
 
-  if (!rte_keymode_valid(key+1,0,TRUE)) rtew_set_keych(key,FALSE);
-
+  if (!rte_keymode_valid(key+1,0,TRUE)) {
+    rtew_set_keych(key,FALSE);
+    if (mainw->ce_thumbs) ce_thumbs_set_keych(key,FALSE);
+  }
   check_clear_all_button();
 
+  if (mainw->ce_thumbs) ce_thumbs_reset_combo(key);
 }
 
 
 static void on_datacon_clicked (GtkButton *button, gpointer user_data) {
-  gint idx=GPOINTER_TO_INT(user_data);
+  int idx=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   int key=(int)(idx/modes);
   int mode=idx-key*modes;
@@ -1747,7 +1757,7 @@ static void on_datacon_clicked (GtkButton *button, gpointer user_data) {
 
 
 static void on_params_clicked (GtkButton *button, gpointer user_data) {
-  gint idx=GPOINTER_TO_INT(user_data);
+  int idx=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   int key=(int)(idx/modes);
   int mode=idx-key*modes;
@@ -1780,7 +1790,7 @@ static void on_params_clicked (GtkButton *button, gpointer user_data) {
   rfx->min_frames=-1;
   keyw=key;
   modew=mode;
-  on_render_fx_pre_activate(NULL,rfx);
+  on_fx_pre_activate(rfx,1,NULL);
 
   // record the key so we know whose parameters to record later
   weed_set_int_value((weed_plant_t *)rfx->source,"host_hotkey",key);
@@ -1867,17 +1877,17 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
   gchar *hashname1;
   gchar *hashname2=(gchar *)g_object_get_data(G_OBJECT(combo),"hashname");
 
-  gint key_mode=GPOINTER_TO_INT(user_data);
+  int key_mode=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   int key=(int)(key_mode/modes);
   int mode=key_mode-key*modes;
-  gint idx=GPOINTER_TO_INT(g_object_get_data(G_OBJECT(combo),"idx"));
+  int idx=GPOINTER_TO_INT(g_object_get_data(G_OBJECT(combo),"idx"));
 
   int error;
 
   register int i;
 
-  if (gtk_combo_box_get_active(combo)==-1) return; // -1 is returned after we set our own text (without the type)
+  if (lives_combo_get_active(combo)==-1) return; // -1 is returned after we set our own text (without the type)
 
   lives_combo_get_active_iter(combo,&iter1);
   model=lives_combo_get_model(combo);
@@ -1918,7 +1928,8 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
   if (num_in_params(filter,TRUE,TRUE)>0) lives_widget_set_sensitive(param_buttons[idx],TRUE);
   else lives_widget_set_sensitive(param_buttons[idx],FALSE);
 
-  if ((weed_plant_has_leaf(filter,"out_parameter_templates")&&weed_get_plantptr_value(filter,"out_parameter_templates",&error)!=NULL)||num_alpha_channels(filter,TRUE)>1) lives_widget_set_sensitive(conx_buttons[idx],TRUE);
+  if ((weed_plant_has_leaf(filter,"out_parameter_templates")&&weed_get_plantptr_value(filter,"out_parameter_templates",&error)!=NULL)||
+      num_alpha_channels(filter,TRUE)>1) lives_widget_set_sensitive(conx_buttons[idx],TRUE);
   else lives_widget_set_sensitive(conx_buttons[idx],FALSE);
 
   // prevents a segfault
@@ -1937,11 +1948,13 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
 
   check_clear_all_button();
 
-  pconx_delete(-1,0,0,key,mode,-1);
-  pconx_delete(key,mode,-1,-1,0,0);
+  pconx_delete(FX_DATA_WILDCARD,0,0,key,mode,FX_DATA_WILDCARD);
+  pconx_delete(key,mode,FX_DATA_WILDCARD,FX_DATA_WILDCARD,0,0);
 
-  cconx_delete(-1,0,0,key,mode,-1);
-  cconx_delete(key,mode,-1,-1,0,0);
+  cconx_delete(FX_DATA_WILDCARD,0,0,key,mode,FX_DATA_WILDCARD);
+  cconx_delete(key,mode,FX_DATA_WILDCARD,FX_DATA_WILDCARD,0,0);
+
+  if (mainw->ce_thumbs) ce_thumbs_reset_combos();
 
 }
 
@@ -2056,7 +2069,7 @@ GtkWidget * create_rte_window (void) {
 
   int modes=rte_getmodespk();
 
-  int idx,error;
+  int idx;
 
   int winsize_h;
   int winsize_v;
@@ -2110,9 +2123,9 @@ GtkWidget * create_rte_window (void) {
   dummy_radio = gtk_radio_button_new (grab_group);
   grab_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (dummy_radio));
 
-  name_list=weed_get_all_names(1);
-  name_type_list=weed_get_all_names(2);
-  hash_list=weed_get_all_names(3);
+  name_list=weed_get_all_names(FX_LIST_NAME);
+  name_type_list=weed_get_all_names(FX_LIST_NAME_AND_TYPE);
+  hash_list=weed_get_all_names(FX_LIST_HASHNAME);
 
   for (i=0;i<prefs->rte_keys_virtual;i++) {
 
@@ -2120,18 +2133,18 @@ GtkWidget * create_rte_window (void) {
     lives_table_attach (GTK_TABLE (table), hbox, i, i+1, 0, 1,
 		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-    lives_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
+    lives_container_set_border_width (LIVES_CONTAINER (hbox), widget_opts.border_width);
     
     label = lives_standard_label_new ((tmp=g_strdup_printf(_("Ctrl-%d"),i+1)));
     g_free(tmp);
 
-    lives_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), label, TRUE, FALSE, widget_opts.packing_width);
 
     hbox2 = lives_hbox_new (FALSE, 0);
 
     key_checks[i] = lives_standard_check_button_new (_("Key active"),FALSE,LIVES_BOX(hbox2),NULL);
     
-    lives_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
 
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_checks[i]),mainw->rte&(GU641<<i));
 
@@ -2141,7 +2154,7 @@ GtkWidget * create_rte_window (void) {
 
 
     hbox2 = lives_hbox_new (FALSE, 0);
-    lives_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
 
     key_grabs[i]=lives_standard_radio_button_new((tmp=g_strdup(_ ("Key grab"))),FALSE,grab_group,LIVES_BOX(hbox2),
 						 (tmp2=g_strdup(_("Grab keyboard for this effect key"))));
@@ -2162,11 +2175,11 @@ GtkWidget * create_rte_window (void) {
       lives_table_attach (GTK_TABLE (table), hbox, i, i+1, j+1, j+2,
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-      lives_container_set_border_width (GTK_CONTAINER (hbox), widget_opts.border_width);
+      lives_container_set_border_width (LIVES_CONTAINER (hbox), widget_opts.border_width);
 
 
       hbox2 = lives_hbox_new (FALSE, 0);
-      lives_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), hbox2, FALSE, FALSE, widget_opts.packing_width);
       
       mode_radios[idx]=lives_standard_radio_button_new(_ ("Mode active"),FALSE,mode_group,LIVES_BOX(hbox2),NULL);
       mode_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (mode_radios[idx]));
@@ -2184,15 +2197,15 @@ GtkWidget * create_rte_window (void) {
       clear_buttons[idx] = gtk_button_new_with_label (_("Clear"));
 
       vbox = lives_vbox_new (FALSE, 0);
-      lives_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, widget_opts.packing_width);
-      lives_container_set_border_width (GTK_CONTAINER (vbox), widget_opts.border_width);
+      lives_box_pack_start (LIVES_BOX (hbox), vbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_container_set_border_width (LIVES_CONTAINER (vbox), widget_opts.border_width);
 
       hbox = lives_hbox_new (FALSE, 0);
-      lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
       nlabels[idx] = lives_standard_label_new (_("Effect name:"));
 
-      lives_box_pack_start (GTK_BOX (hbox), nlabels[idx], FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), nlabels[idx], FALSE, FALSE, widget_opts.packing_width);
 
       // create combo entry model
       model=rte_window_fx_model();
@@ -2203,7 +2216,7 @@ GtkWidget * create_rte_window (void) {
 
       g_object_set_data (G_OBJECT(combo), "hashname", (gpointer)g_strdup(""));
       g_object_set_data (G_OBJECT(combo), "idx", GINT_TO_POINTER(idx));
-      lives_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), combo, TRUE, TRUE, widget_opts.packing_width);
 
 
       combo_entries[idx] = lives_combo_get_entry(LIVES_COMBO(combo));
@@ -2214,7 +2227,7 @@ GtkWidget * create_rte_window (void) {
       lives_entry_set_editable (LIVES_ENTRY (combo_entries[idx]), FALSE);
       
       hbox = lives_hbox_new (FALSE, 0);
-      lives_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
       g_signal_connect(GTK_OBJECT (combo), "changed",
 		       G_CALLBACK (fx_changed),GINT_TO_POINTER(i*rte_getmodespk()+j));
@@ -2233,20 +2246,21 @@ GtkWidget * create_rte_window (void) {
       
       type_label_set_text(i,j);
 
-      lives_box_pack_start (GTK_BOX (hbox), type_labels[idx], FALSE, FALSE, widget_opts.packing_width);
-      lives_box_pack_end (GTK_BOX (hbox), info_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
-      lives_box_pack_end (GTK_BOX (hbox), conx_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
-      lives_box_pack_end (GTK_BOX (hbox), param_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
-      lives_box_pack_end (GTK_BOX (hbox), clear_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), type_labels[idx], FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_end (LIVES_BOX (hbox), info_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_end (LIVES_BOX (hbox), conx_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_end (LIVES_BOX (hbox), param_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_end (LIVES_BOX (hbox), clear_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
 
       filter=rte_keymode_get_filter(i+1,j);
 
       if (num_in_params(filter,TRUE,TRUE)>0) lives_widget_set_sensitive(param_buttons[idx],TRUE);
       else lives_widget_set_sensitive(param_buttons[idx],FALSE);
 
+      /*
       if ((weed_plant_has_leaf(filter,"out_parameter_templates")&&weed_get_plantptr_value(filter,"out_parameter_templates",&error)!=NULL)||num_alpha_channels(filter,TRUE)>1) lives_widget_set_sensitive(conx_buttons[idx],TRUE);
       else lives_widget_set_sensitive(conx_buttons[idx],FALSE);
-
+      */
 
 
       }
@@ -2257,30 +2271,30 @@ GtkWidget * create_rte_window (void) {
 
   top_vbox = lives_vbox_new (FALSE, 0);
 
-  lives_box_pack_start (GTK_BOX (top_vbox), dummy_radio, FALSE, FALSE, 0);
-  lives_box_pack_start (GTK_BOX (top_vbox), scrolledwindow, TRUE, TRUE, widget_opts.packing_height);
+  lives_box_pack_start (LIVES_BOX (top_vbox), dummy_radio, FALSE, FALSE, 0);
+  lives_box_pack_start (LIVES_BOX (top_vbox), scrolledwindow, TRUE, TRUE, widget_opts.packing_height);
 
-  lives_container_add (GTK_CONTAINER (rte_window), top_vbox);
+  lives_container_add (LIVES_CONTAINER (rte_window), top_vbox);
 
   hbuttonbox = lives_hbutton_box_new ();
-  lives_box_pack_start (GTK_BOX (top_vbox), hbuttonbox, FALSE, TRUE, widget_opts.packing_height*2);
+  lives_box_pack_start (LIVES_BOX (top_vbox), hbuttonbox, FALSE, TRUE, widget_opts.packing_height*2);
 
-  lives_container_add (GTK_CONTAINER (hbuttonbox), clear_all_button);
+  lives_container_add (LIVES_CONTAINER (hbuttonbox), clear_all_button);
   lives_widget_set_can_focus_and_default (clear_all_button);
 
   save_keymap_button = lives_button_new_with_mnemonic (_("_Save as default keymap"));
 
-  lives_container_add (GTK_CONTAINER (hbuttonbox), save_keymap_button);
+  lives_container_add (LIVES_CONTAINER (hbuttonbox), save_keymap_button);
   lives_widget_set_can_focus_and_default (save_keymap_button);
 
   load_keymap_button = lives_button_new_with_mnemonic (_("_Load default keymap"));
 
-  lives_container_add (GTK_CONTAINER (hbuttonbox), load_keymap_button);
+  lives_container_add (LIVES_CONTAINER (hbuttonbox), load_keymap_button);
   lives_widget_set_can_focus_and_default (load_keymap_button);
 
   ok_button = lives_button_new_with_mnemonic (_("Close _window"));
 
-  lives_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
+  lives_container_add (LIVES_CONTAINER (hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default (ok_button);
 
 #if !GTK_CHECK_VERSION(3,0,0)
@@ -2318,9 +2332,9 @@ GtkWidget * create_rte_window (void) {
   lives_widget_hide(dummy_radio);
 
   if (prefs->gui_monitor!=0) {
-    gint xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width-
+    int xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width-
 						    lives_widget_get_allocation_width(rte_window))/2;
-    gint ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height-
+    int ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height-
 						    lives_widget_get_allocation_height(rte_window))/2;
     gtk_window_set_screen(GTK_WINDOW(rte_window),mainw->mgeom[prefs->gui_monitor-1].screen);
     lives_window_move(GTK_WINDOW(rte_window),xcen,ycen);
@@ -2359,7 +2373,9 @@ void on_assign_rte_keys_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 void rtew_set_keych (int key, boolean on) {
   g_signal_handler_block(key_checks[key],ch_fns[key]);
+  pthread_mutex_lock(&mainw->gtk_mutex);
   lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_checks[key]),on);
+  pthread_mutex_unlock(&mainw->gtk_mutex);
   g_signal_handler_unblock(key_checks[key],ch_fns[key]);
 }
 
@@ -2377,7 +2393,9 @@ void rtew_set_keygr (int key) {
 
 void rtew_set_mode_radio (int key, int mode) {
   int modes=rte_getmodespk();
+  g_signal_handler_block(mode_radios[key*modes+mode],mode_ra_fns[key*modes+mode]);
   lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(mode_radios[key*modes+mode]),TRUE);
+  g_signal_handler_unblock(mode_radios[key*modes+mode],mode_ra_fns[key*modes+mode]);
 }
 
 
@@ -2400,15 +2418,15 @@ void redraw_pwindow (int key, int mode) {
     if (rfx->is_template||(key==keyw&&mode==modew)) {
       // rip out the contents
       if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
-      child_list=gtk_container_get_children(GTK_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fx_dialog[1]))));
+      child_list=gtk_container_get_children(LIVES_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fx_dialog[1]))));
       action_area=lives_dialog_get_action_area(LIVES_DIALOG(fx_dialog[1]));
-      gtk_container_set_focus_child(GTK_CONTAINER(action_area),NULL);
+      gtk_container_set_focus_child(LIVES_CONTAINER(action_area),NULL);
       for (i=0;i<g_list_length(child_list);i++) {
 	GtkWidget *widget=(GtkWidget *)g_list_nth_data(child_list,i);
 	if (widget!=action_area) {
 	  // we have to do this, because using lives_widget_destroy() here 
 	  // can causes a crash [bug in gtk+ ???]
-	  gtk_widget_reparent (widget,mainw->invis);
+	  lives_widget_reparent (widget,mainw->invis);
 	}
       }
       if (child_list!=NULL) g_list_free(child_list);
@@ -2431,6 +2449,8 @@ void restore_pwindow (lives_rfx_t *rfx) {
 
 
 void update_pwindow (int key, int i, GList *list) {
+  // called only from weed_set_blend_factor() and from setting param in ce_thumbs
+
   const weed_plant_t *inst;
   lives_rfx_t *rfx;
   int keyw,modew;
@@ -2441,13 +2461,15 @@ void update_pwindow (int key, int i, GList *list) {
     if (key==keyw) {
       if ((inst=rte_keymode_get_instance(key+1,modew))==NULL) return;
       rfx=(lives_rfx_t *)g_object_get_data(G_OBJECT(fx_dialog[1]),"rfx");
+      mainw->block_param_updates=TRUE;
       set_param_from_list(list,&rfx->params[i],0,TRUE,TRUE);
+      mainw->block_param_updates=FALSE;
     }
   }
 }
 
 void rte_set_defs_activate (GtkMenuItem *menuitem, gpointer user_data) {
-  gint idx=GPOINTER_TO_INT(user_data);
+  int idx=GPOINTER_TO_INT(user_data);
   weed_plant_t *filter=get_weed_filter(idx);
   lives_rfx_t *rfx;
 
@@ -2459,7 +2481,7 @@ void rte_set_defs_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
   rfx=weed_to_rfx(filter,TRUE);
   rfx->min_frames=-1;
-  on_render_fx_pre_activate(NULL,rfx);
+  on_fx_pre_activate(rfx,1,NULL);
 
 }
 
@@ -2632,8 +2654,8 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
     }
   }
   else {
-    gint key=GPOINTER_TO_INT (g_object_get_data (G_OBJECT (fx_dialog[1]),"key"));
-    gint mode=GPOINTER_TO_INT (g_object_get_data (G_OBJECT (fx_dialog[1]),"mode"));
+    int key=GPOINTER_TO_INT (g_object_get_data (G_OBJECT (fx_dialog[1]),"key"));
+    int mode=GPOINTER_TO_INT (g_object_get_data (G_OBJECT (fx_dialog[1]),"mode"));
     set_key_defaults(inst,key,mode);
   }
 
@@ -2644,7 +2666,7 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
   // redraw the window
 
   if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
-  child_list=gtk_container_get_children(GTK_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fxdialog))));
+  child_list=gtk_container_get_children(LIVES_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fxdialog))));
 
   action_area=lives_dialog_get_action_area(LIVES_DIALOG (fxdialog));
 
@@ -2653,7 +2675,7 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
     if (widget!=action_area) {
       // we have to do this, because using lives_widget_destroy() here 
       // can causes a crash [bug in gtk+ ???]
-      gtk_widget_reparent (widget,mainw->invis);
+      lives_widget_reparent (widget,mainw->invis);
     }
   }
   
