@@ -291,9 +291,8 @@ lives_painter_format_t lives_painter_image_surface_get_format(lives_painter_surf
 
 ////////////////////////////////////////////////////////
 
-#ifdef GUI_GTK
-static void set_label_state(GtkWidget *widget, LiVESWidgetState state, gpointer labelp) {
-  GtkWidget *label=(GtkWidget *)labelp;
+static void set_label_state(LiVESWidget *widget, LiVESWidgetState state, livespointer labelp) {
+  LiVESWidget *label=(LiVESWidget *)labelp;
   if (lives_widget_get_sensitive(widget)&&!lives_widget_get_sensitive(label)) {
     lives_widget_set_sensitive(label,TRUE);
   }
@@ -301,9 +300,8 @@ static void set_label_state(GtkWidget *widget, LiVESWidgetState state, gpointer
     lives_widget_set_sensitive(label,FALSE);
   }
 }
-#endif
 
-LIVES_INLINE void lives_object_unref(LiVESObjectPtr object) {
+LIVES_INLINE void lives_object_unref(livespointer object) {
 #ifdef GUI_GTK
   g_object_unref(object);
 #endif
@@ -381,6 +379,20 @@ LIVES_INLINE void lives_widget_set_size_request(LiVESWidget *widget, int width,
 }
 
 
+LIVES_INLINE void lives_widget_reparent(LiVESWidget *widget, LiVESWidget *new_parent) {
+#ifdef GUI_GTK
+  gtk_widget_reparent(widget,new_parent);
+#endif
+}
+
+
+LIVES_INLINE void lives_widget_set_app_paintable(LiVESWidget *widget, boolean paintable) {
+#ifdef GUI_GTK
+  gtk_widget_set_app_paintable(widget,paintable);
+#endif
+}
+
+
 
 LIVES_INLINE int lives_dialog_run(LiVESDialog *dialog) {
 #ifdef GUI_GTK
@@ -481,6 +493,23 @@ LIVES_INLINE LiVESWidgetColor *lives_widget_color_copy(LiVESWidgetColor *c1, con
 return c0;
 }
 
+LIVES_INLINE LiVESWidget *lives_event_box_new(void) {
+  LiVESWidget *eventbox=NULL;
+#ifdef GUI_GTK
+  eventbox=gtk_event_box_new();
+#endif
+  return eventbox;
+}
+
+
+LIVES_INLINE LiVESWidget *lives_image_new(void) {
+  LiVESWidget *image=NULL;
+#ifdef GUI_GTK
+  image=gtk_image_new();
+#endif
+  return image;
+}
+
 
 
 LIVES_INLINE LiVESWidget *lives_image_new_from_stock(const char *stock_id, lives_icon_size_t size) {
@@ -665,7 +694,7 @@ LIVES_INLINE LiVESPixbuf *lives_pixbuf_new(boolean has_alpha, int width, int hei
 
 LIVES_INLINE LiVESPixbuf *lives_pixbuf_new_from_data (const unsigned char *buf, boolean has_alpha, int width, int height, 
 						      int rowstride, LiVESPixbufDestroyNotify lives_free_buffer_fn, 
-						      gpointer destroy_fn_data) {
+						      livespointer destroy_fn_data) {
 
 #ifdef GUI_GTK
   return gdk_pixbuf_new_from_data ((const guchar *)buf, GDK_COLORSPACE_RGB, has_alpha, 8, width, height, rowstride, 
@@ -868,6 +897,13 @@ LIVES_INLINE void lives_box_set_homogeneous(LiVESBox *box, boolean homogenous) {
 }
 
 
+LIVES_INLINE void lives_box_reorder_child(LiVESBox *box, LiVESWidget *child, int pos) {
+#ifdef GUI_GTK
+  gtk_box_reorder_child(box,child,pos);
+#endif
+}
+
+
 LIVES_INLINE void lives_box_set_spacing(LiVESBox *box, int spacing) {
 #ifdef GUI_GTK
   gtk_box_set_spacing(box,spacing);
@@ -1051,6 +1087,46 @@ LIVES_INLINE LiVESWidget *lives_vscrollbar_new(LiVESAdjustment *adj) {
 }
 
 
+LIVES_INLINE LiVESWidget *lives_label_new(const char *text) {
+  LiVESWidget *label=NULL;
+#ifdef GUI_GTK
+
+  label=gtk_label_new(text);
+
+  gtk_label_set_justify (GTK_LABEL (label), widget_opts.justify);
+
+  gtk_label_set_line_wrap (GTK_LABEL (label), widget_opts.line_wrap);
+#endif
+
+  return label;
+}
+
+
+LIVES_INLINE LiVESWidget *lives_arrow_new(lives_arrow_t arrow_type, lives_shadow_t shadow_type) {
+  LiVESWidget *arrow=NULL;
+#ifdef GUI_GTK
+  arrow=gtk_arrow_new(arrow_type,shadow_type);
+#endif
+  return arrow;
+}
+
+
+LIVES_INLINE LiVESWidget *lives_alignment_new(float xalign, float yalign, float xscale, float yscale) {
+  LiVESWidget *alignment=NULL;
+#ifdef GUI_GTK
+  alignment=gtk_alignment_new(xalign,yalign,xscale,yscale);
+#endif
+  return alignment;
+}
+
+
+LIVES_INLINE void lives_alignment_set(LiVESAlignment *alignment, float xalign, float yalign, float xscale, float yscale) {
+#ifdef GUI_GTK
+  gtk_alignment_set(alignment,xalign,yalign,xscale,yscale);
+#endif
+}
+
+
 LIVES_INLINE LiVESWidget *lives_combo_new(void) {
   LiVESWidget *combo=NULL;
 #ifdef GUI_GTK
@@ -1161,6 +1237,14 @@ LIVES_INLINE boolean lives_combo_get_active_iter(LiVESCombo *combo, LiVESTreeIte
 }
 
 
+LIVES_INLINE int lives_combo_get_active(LiVESCombo *combo) {
+#ifdef GUI_GTK
+  return gtk_combo_box_get_active(combo);
+#endif
+  return FALSE;
+}
+
+
 LIVES_INLINE LiVESWidget *lives_button_new_with_mnemonic(const char *label) {
   LiVESWidget *button=NULL;
 #ifdef GUI_GTK
@@ -1643,6 +1727,13 @@ LIVES_INLINE void lives_entry_set_text(LiVESEntry *entry, const char *text) {
 }
 
 
+LIVES_INLINE void lives_scrolled_window_set_policy(LiVESScrolledWindow *scrolledwindow, lives_policy_t hpolicy, 
+						   lives_policy_t vpolicy) {
+#ifdef GUI_GTK
+  gtk_scrolled_window_set_policy (scrolledwindow, hpolicy, vpolicy);
+#endif
+
+}
 
 LIVES_INLINE boolean lives_dialog_set_has_separator(LiVESDialog *dialog, boolean has) {
   // return TRUE if implemented
@@ -1682,6 +1773,51 @@ LIVES_INLINE boolean lives_widget_set_vexpand(LiVESWidget *widget, boolean state
 }
 
 
+LIVES_INLINE LiVESWidget *lives_grid_new(void) {
+  LiVESWidget *grid=NULL;
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(3,2,0)  // required for grid widget
+  grid=gtk_grid_new();
+#endif
+#endif
+  return grid;
+}
+
+
+LIVES_INLINE boolean lives_grid_set_row_spacing(LiVESGrid *grid, uint32_t spacing) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(3,2,0)  // required for grid widget
+  gtk_grid_set_row_spacing(grid,spacing);
+  return TRUE;
+#endif
+#endif
+  return FALSE;
+}
+
+
+LIVES_INLINE boolean lives_grid_set_column_spacing(LiVESGrid *grid, uint32_t spacing) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(3,2,0)  // required for grid widget
+  gtk_grid_set_column_spacing(grid,spacing);
+  return TRUE;
+#endif
+#endif
+  return FALSE;
+}
+
+
+LIVES_INLINE boolean lives_grid_attach_next_to(LiVESGrid *grid, LiVESWidget *child, LiVESWidget *sibling, 
+					       lives_position_t side, int width, int height) {
+#ifdef GUI_GTK
+#if GTK_CHECK_VERSION(3,2,0)  // required for grid widget
+  gtk_grid_attach_next_to(grid,child,sibling,side,width,height);
+  return TRUE;
+#endif
+#endif
+  return FALSE;
+}
+
+
 LIVES_INLINE LiVESWidget *lives_menu_new(void) {
   LiVESWidget *menu;
 #ifdef GUI_GTK
@@ -2103,20 +2239,14 @@ LiVESWidget *lives_volume_button_new(LiVESOrientation orientation, LiVESAdjustme
 }
 
 
-
 LiVESWidget *lives_standard_label_new(const char *text) {
   LiVESWidget *label=NULL;
-#ifdef GUI_GTK
 
-  label=gtk_label_new(text);
+  label=lives_label_new(text);
 
   if (widget_opts.apply_theme) {
     lives_widget_apply_theme(label, LIVES_WIDGET_STATE_NORMAL);
   }
-  gtk_label_set_justify (GTK_LABEL (label), widget_opts.justify);
-
-  gtk_label_set_line_wrap (GTK_LABEL (label), widget_opts.line_wrap);
-#endif
 
   return label;
 }
@@ -2159,7 +2289,7 @@ LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_
   widget_opts.last_label=NULL;
 
   if (labeltext!=NULL) {
-    eventbox=gtk_event_box_new();
+    eventbox=lives_event_box_new();
     if (tooltip!=NULL) lives_tooltips_copy(eventbox,checkbutton);
 
     if (use_mnemonic) {
@@ -2167,7 +2297,7 @@ LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_
     }
     else label=lives_standard_label_new (labeltext);
 
-    lives_container_add(GTK_CONTAINER(eventbox),label);
+    lives_container_add(LIVES_CONTAINER(eventbox),label);
 
     g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
 		      G_CALLBACK (label_act_toggle),
@@ -2187,19 +2317,19 @@ LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_
       if (!widget_opts.no_gui) {
 	lives_widget_show(hbox);
       }
-      lives_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
     }
     
     lives_box_set_homogeneous(LIVES_BOX(hbox),FALSE);
     
     
     if (widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
     
-    lives_box_pack_start (GTK_BOX (hbox), checkbutton, widget_opts.expand==LIVES_EXPAND_EXTRA, FALSE, eventbox==NULL?0:widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), checkbutton, widget_opts.expand==LIVES_EXPAND_EXTRA, FALSE, eventbox==NULL?0:widget_opts.packing_width);
 
     if (!widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
 
   }
 
@@ -2250,9 +2380,9 @@ LiVESWidget *lives_standard_radio_button_new(const char *labeltext, boolean use_
 
     widget_opts.last_label=label;
     
-    eventbox=gtk_event_box_new();
+    eventbox=lives_event_box_new();
     if (tooltip!=NULL) lives_tooltips_copy(eventbox,radiobutton);
-    lives_container_add(GTK_CONTAINER(eventbox),label);
+    lives_container_add(LIVES_CONTAINER(eventbox),label);
 
     g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
 		      G_CALLBACK (label_act_toggle),
@@ -2271,18 +2401,18 @@ LiVESWidget *lives_standard_radio_button_new(const char *labeltext, boolean use_
       if (!widget_opts.no_gui) {
 	lives_widget_show(hbox);
       }
-      lives_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
     }
     
     lives_box_set_homogeneous(LIVES_BOX(hbox),FALSE);
     
     if (widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
 
-    lives_box_pack_start (GTK_BOX (hbox), radiobutton, widget_opts.expand==LIVES_EXPAND_EXTRA, FALSE, eventbox==NULL?0:widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), radiobutton, widget_opts.expand==LIVES_EXPAND_EXTRA, FALSE, eventbox==NULL?0:widget_opts.packing_width);
 
     if (!widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
   }
 
   if (label!=NULL) {
@@ -2354,9 +2484,9 @@ LiVESWidget *lives_standard_spin_button_new(const char *labeltext, boolean use_m
     
     widget_opts.last_label=label;
 
-    eventbox=gtk_event_box_new();
+    eventbox=lives_event_box_new();
     if (tooltip!=NULL) lives_tooltips_copy(eventbox,spinbutton);
-    lives_container_add(GTK_CONTAINER(eventbox),label);
+    lives_container_add(LIVES_CONTAINER(eventbox),label);
     
     if (widget_opts.apply_theme) {
       lives_widget_apply_theme(eventbox, LIVES_WIDGET_STATE_NORMAL);
@@ -2370,23 +2500,23 @@ LiVESWidget *lives_standard_spin_button_new(const char *labeltext, boolean use_m
       if (!widget_opts.no_gui) {
 	lives_widget_show(hbox);
       }
-      lives_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
       expand=widget_opts.expand!=LIVES_EXPAND_NONE;
     }
 
     lives_box_set_homogeneous(LIVES_BOX(hbox),FALSE);
 
     if (!widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
     
     if (expand) add_fill_to_box(LIVES_BOX(hbox));
 
-    lives_box_pack_start (GTK_BOX (hbox), spinbutton, widget_opts.expand==LIVES_EXPAND_EXTRA, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), spinbutton, widget_opts.expand==LIVES_EXPAND_EXTRA, FALSE, widget_opts.packing_width);
     
     if (expand) add_fill_to_box(LIVES_BOX(hbox));
 
     if (widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
   }
 
   if (label!=NULL) {
@@ -2439,9 +2569,9 @@ LiVESWidget *lives_standard_combo_new (const char *labeltext, boolean use_mnemon
 
     widget_opts.last_label=label;
     
-    eventbox=gtk_event_box_new();
+    eventbox=lives_event_box_new();
     if (tooltip!=NULL) lives_tooltips_copy(eventbox,combo);
-    lives_container_add(GTK_CONTAINER(eventbox),label);
+    lives_container_add(LIVES_CONTAINER(eventbox),label);
     
     if (widget_opts.apply_theme) {
       lives_widget_apply_theme(eventbox, LIVES_WIDGET_STATE_NORMAL);
@@ -2452,27 +2582,27 @@ LiVESWidget *lives_standard_combo_new (const char *labeltext, boolean use_mnemon
     if (LIVES_IS_HBOX(box)) hbox=GTK_WIDGET(box);
     else {
       hbox = lives_hbox_new (FALSE, 0);
-      lives_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
     }
 
     lives_box_set_homogeneous(LIVES_BOX(hbox),FALSE);
 
     if (widget_opts.expand==LIVES_EXPAND_DEFAULT) {
       GtkWidget *label=lives_standard_label_new("");
-      lives_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
+      lives_box_pack_start (LIVES_BOX (hbox), label, TRUE, FALSE, 0);
     }
     
     if (!widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
-    lives_box_pack_start (GTK_BOX (hbox), combo, widget_opts.expand!=LIVES_EXPAND_NONE, 
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), combo, widget_opts.expand!=LIVES_EXPAND_NONE, 
 			widget_opts.expand==LIVES_EXPAND_EXTRA, eventbox==NULL?0:widget_opts.packing_width);
     if (widget_opts.swap_label&&eventbox!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), eventbox, FALSE, FALSE, widget_opts.packing_width);
 
 
     if (widget_opts.expand==LIVES_EXPAND_DEFAULT) {
       GtkWidget *label=lives_standard_label_new("");
-      lives_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
+      lives_box_pack_start (LIVES_BOX (hbox), label, TRUE, FALSE, 0);
     }
 
 
@@ -2547,18 +2677,18 @@ LiVESWidget *lives_standard_entry_new(const char *labeltext, boolean use_mnemoni
       if (!widget_opts.no_gui) {
 	lives_widget_show(hbox);
       }
-      lives_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
+      lives_box_pack_start (LIVES_BOX (box), hbox, FALSE, FALSE, widget_opts.packing_height);
     }
     
     lives_box_set_homogeneous(LIVES_BOX(hbox),FALSE);
 
     if (!widget_opts.swap_label&&label!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
     
-    lives_box_pack_start (GTK_BOX (hbox), entry, widget_opts.expand!=LIVES_EXPAND_NONE, dispwidth==-1, widget_opts.packing_width);
+    lives_box_pack_start (LIVES_BOX (hbox), entry, widget_opts.expand!=LIVES_EXPAND_NONE, dispwidth==-1, widget_opts.packing_width);
     
     if (widget_opts.swap_label&&label!=NULL)
-      lives_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
+      lives_box_pack_start (LIVES_BOX (hbox), label, FALSE, FALSE, widget_opts.packing_width);
   }
 
   if (label!=NULL) {
@@ -2596,7 +2726,7 @@ LiVESWidget *lives_standard_dialog_new(const char *title, boolean add_std_button
   lives_widget_set_hexpand(dialog,TRUE);
   lives_widget_set_vexpand(dialog,TRUE);
 
-  lives_container_set_border_width (GTK_CONTAINER (dialog), widget_opts.border_width*2);
+  lives_container_set_border_width (LIVES_CONTAINER (dialog), widget_opts.border_width*2);
 
   if (widget_opts.apply_theme) {
     lives_widget_apply_theme(dialog, LIVES_WIDGET_STATE_NORMAL);
@@ -2679,12 +2809,12 @@ LiVESWidget *lives_standard_scrolled_window_new(int width, int height, LiVESWidg
   LiVESWidget *swchild;
 
   scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  lives_scrolled_window_set_policy (LIVES_SCROLLED_WINDOW (scrolledwindow), LIVES_POLICY_AUTOMATIC, LIVES_POLICY_AUTOMATIC);
 
   if (widget_opts.apply_theme) {
     lives_widget_set_hexpand(scrolledwindow,TRUE);
     lives_widget_set_vexpand(scrolledwindow,TRUE);
-    lives_container_set_border_width (GTK_CONTAINER (scrolledwindow), widget_opts.border_width);
+    lives_container_set_border_width (LIVES_CONTAINER (scrolledwindow), widget_opts.border_width);
   }
 
   if (child!=NULL) {
@@ -2695,10 +2825,19 @@ LiVESWidget *lives_standard_scrolled_window_new(int width, int height, LiVESWidg
 #endif 
       {
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindow), child);
-	gtk_viewport_set_shadow_type (GTK_VIEWPORT (lives_bin_get_child (LIVES_BIN (scrolledwindow))),GTK_SHADOW_IN);
       }
-    else 
-      lives_container_add (GTK_CONTAINER (scrolledwindow), child);
+    else {
+      if (widget_opts.expand!=LIVES_EXPAND_NONE) {
+	LiVESWidget *align;
+	align=lives_alignment_new(.5,0.,0.,0.);
+	lives_container_add (LIVES_CONTAINER (align), child);
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindow), align);
+      }
+      else {
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwindow), child);
+      }
+    }
+    gtk_viewport_set_shadow_type (GTK_VIEWPORT (lives_bin_get_child (LIVES_BIN (scrolledwindow))),LIVES_SHADOW_IN);
   }
 
   swchild=lives_bin_get_child(LIVES_BIN(scrolledwindow));
@@ -2716,7 +2855,7 @@ LiVESWidget *lives_standard_scrolled_window_new(int width, int height, LiVESWidg
     lives_widget_apply_theme(swchild, LIVES_WIDGET_STATE_NORMAL);
     lives_widget_set_hexpand(swchild,TRUE);
     lives_widget_set_vexpand(swchild,TRUE);
-    if (GTK_IS_CONTAINER(child)) lives_container_set_border_width (GTK_CONTAINER (child), widget_opts.border_width>>1);
+    if (GTK_IS_CONTAINER(child)) lives_container_set_border_width (LIVES_CONTAINER (child), widget_opts.border_width>>1);
   }
 #endif
   return scrolledwindow;
@@ -2742,11 +2881,11 @@ LiVESWidget *lives_standard_expander_new(const char *ltext, boolean use_mnemonic
     lives_widget_apply_theme(expander, LIVES_WIDGET_STATE_NORMAL);
   }
   
-  gtk_container_forall(GTK_CONTAINER(expander),set_child_colour,GINT_TO_POINTER(TRUE));
+  gtk_container_forall(LIVES_CONTAINER(expander),set_child_colour,GINT_TO_POINTER(TRUE));
 
   lives_box_pack_start (parent, expander, FALSE, FALSE, widget_opts.packing_height);
 
-  lives_container_add (GTK_CONTAINER (expander), child);
+  lives_container_add (LIVES_CONTAINER (expander), child);
 #endif
 
   return expander;
@@ -2759,8 +2898,8 @@ LiVESWidget *lives_standard_file_button_new(boolean is_dir, const char *def_dir)
   GtkWidget *image = lives_image_new_from_stock ("gtk-open", LIVES_ICON_SIZE_BUTTON);
   fbutton = gtk_button_new ();
   g_object_set_data(G_OBJECT(fbutton),"is_dir",GINT_TO_POINTER(is_dir));
-  if (def_dir!=NULL) g_object_set_data(G_OBJECT(fbutton),"def_dir",(gpointer)def_dir);
-  lives_container_add (GTK_CONTAINER (fbutton), image);
+  if (def_dir!=NULL) g_object_set_data(G_OBJECT(fbutton),"def_dir",(livespointer)def_dir);
+  lives_container_add (LIVES_CONTAINER (fbutton), image);
 #endif
   return fbutton;
 }
@@ -2834,7 +2973,7 @@ LIVES_INLINE void toggle_button_toggle (LiVESToggleButton *tbutton) {
 }
 
 
-void set_child_colour(LiVESWidget *widget, gpointer set_allx) {
+void set_child_colour(LiVESWidget *widget, livespointer set_allx) {
   boolean set_all=GPOINTER_TO_INT(set_allx);
 
   if (!set_all&&GTK_IS_BUTTON(widget)) return;
@@ -2876,7 +3015,7 @@ void text_view_set_text(LiVESTextView *textview, const gchar *text, int len) {
 
 
 int get_box_child_index (LiVESBox *box, LiVESWidget *tchild) {
-  GList *list=gtk_container_get_children(GTK_CONTAINER(box));
+  GList *list=gtk_container_get_children(LIVES_CONTAINER(box));
   GtkWidget *child;
   register int i=0;
 
@@ -2928,7 +3067,9 @@ void lives_widget_context_update(void) {
     mt_needs_idlefunc=TRUE;
   }
 
+  if (pthread_mutex_trylock(&mainw->gtk_mutex)) return;
   while (!mainw->is_exiting&&g_main_context_iteration(NULL,FALSE));
+  pthread_mutex_unlock(&mainw->gtk_mutex);
 
   if (!mainw->is_exiting&&mt_needs_idlefunc) mainw->multitrack->idlefunc=mt_idle_add(mainw->multitrack);
 #endif
@@ -3073,7 +3214,7 @@ void lives_widget_set_can_focus_and_default(LiVESWidget *widget) {
 
 
 
-void lives_general_button_clicked (LiVESButton *button, LiVESObjectPtr data_to_free) {
+void lives_general_button_clicked (LiVESButton *button, livespointer data_to_free) {
   // destroy the button top-level and free data
   lives_widget_destroy(lives_widget_get_toplevel(LIVES_WIDGET(button)));
   lives_widget_context_update();
@@ -3083,16 +3224,26 @@ void lives_general_button_clicked (LiVESButton *button, LiVESObjectPtr data_to_f
 
 
 LiVESWidget *add_hsep_to_box (LiVESBox *box) {
-  LiVESWidget *widget=NULL;
   LiVESWidget *hseparator = lives_hseparator_new ();
-  lives_box_pack_start (box, hseparator, FALSE, FALSE, widget_opts.packing_height>>1);
+  lives_box_pack_start (box, hseparator, FALSE, FALSE, widget_opts.packing_width>>1);
   if (!widget_opts.no_gui) 
     lives_widget_show(hseparator);
   if (widget_opts.apply_theme) {
     lives_widget_apply_theme(hseparator, LIVES_WIDGET_STATE_NORMAL);
   }
-  widget=hseparator;
-  return widget;
+  return hseparator;
+}
+
+
+LiVESWidget *add_vsep_to_box (LiVESBox *box) {
+  LiVESWidget *vseparator = lives_vseparator_new ();
+  lives_box_pack_start (box, vseparator, FALSE, FALSE, widget_opts.packing_height>>1);
+  if (!widget_opts.no_gui) 
+    lives_widget_show(vseparator);
+  if (widget_opts.apply_theme) {
+    lives_widget_apply_theme(vseparator, LIVES_WIDGET_STATE_NORMAL);
+  }
+  return vseparator;
 }
 
 #ifdef GUI_GTK
