@@ -114,6 +114,7 @@ typedef GtkSpinButton                     LiVESSpinButton;
 typedef GtkLabel                          LiVESLabel;
 typedef GtkImage                          LiVESImage;
 typedef GtkFileChooser                    LiVESFileChooser;
+typedef GtkAlignment                      LiVESAlignment;
 typedef GtkMenu                           LiVESMenu;
 typedef GtkMenuItem                       LiVESMenuItem;
 typedef GtkCheckMenuItem                  LiVESCheckMenuItem;
@@ -122,6 +123,7 @@ typedef GtkTreeView                       LiVESTreeView;
 typedef GtkTreeModel                      LiVESTreeModel;
 typedef GtkTreeIter                       LiVESTreeIter;
 typedef GtkTable                          LiVESTable;
+typedef GtkScrolledWindow                 LiVESScrolledWindow;
 
 #if GTK_CHECK_VERSION(2,14,0)
 typedef GtkScaleButton                    LiVESScaleButton;
@@ -129,6 +131,12 @@ typedef GtkScaleButton                    LiVESScaleButton;
 typedef GtkRange                          LiVESScaleButton;
 #endif
 
+#if GTK_CHECK_VERSION(3,2,0)
+typedef GtkGrid                           LiVESGrid;
+#else
+typedef GtkWidget                         LiVESGrid;
+#endif
+
 typedef GClosure                          LiVESWidgetClosure;
 
 
@@ -198,6 +206,40 @@ typedef enum {
 } lives_icon_size_t;
 
 
+// scrolledwindow policies
+typedef enum {
+  LIVES_POLICY_ALWAYS=GTK_POLICY_ALWAYS,
+  LIVES_POLICY_AUTOMATIC=GTK_POLICY_AUTOMATIC,
+  LIVES_POLICY_NEVER=GTK_POLICY_NEVER
+} lives_policy_t;
+
+
+typedef enum {
+  LIVES_POS_LEFT=GTK_POS_LEFT,
+  LIVES_POS_RIGHT=GTK_POS_RIGHT,
+  LIVES_POS_TOP=GTK_POS_TOP,
+  LIVES_POS_BOTTOM=GTK_POS_BOTTOM
+} lives_position_t;
+
+
+typedef enum {
+  LIVES_SHADOW_NONE=GTK_SHADOW_NONE,
+  LIVES_SHADOW_IN=GTK_SHADOW_IN,
+  LIVES_SHADOW_OUT=GTK_SHADOW_OUT,
+  LIVES_SHADOW_ETCHED_IN=GTK_SHADOW_ETCHED_IN,
+  LIVES_SHADOW_ETCHED_OUT=GTK_SHADOW_ETCHED_OUT
+} lives_shadow_t;
+
+
+typedef enum {
+  LIVES_ARROW_UP=GTK_ARROW_UP,
+  LIVES_ARROW_DOWN=GTK_ARROW_DOWN,
+  LIVES_ARROW_LEFT=GTK_ARROW_LEFT,
+  LIVES_ARROW_RIGHT=GTK_ARROW_RIGHT,
+  LIVES_ARROW_NONE=GTK_ARROW_NONE
+} lives_arrow_t;
+
+
 #define LIVES_ACCEL_VISIBLE GTK_ACCEL_VISIBLE
   
 
@@ -234,13 +276,14 @@ typedef GdkPixbufDestroyNotify            LiVESPixbufDestroyNotify;
 
 typedef GdkInterpType                     LiVESInterpType;
 
-typedef gpointer                          LiVESObjectPtr;
+typedef gpointer                          livespointer;
 
 #define LIVES_WIDGET(widget) GTK_WIDGET(widget)
 #define LIVES_PIXBUF(widget) GDK_PIXBUF(widget)
 #define LIVES_WINDOW(widget) GTK_WINDOW(widget)
 #define LIVES_XWINDOW(widget) GDK_WINDOW(widget)
 #define LIVES_BOX(widget) GTK_BOX(widget)
+#define LIVES_EVENT_BOX(widget) GTK_EVENT_BOX(widget)
 #define LIVES_ENTRY(widget) GTK_ENTRY(widget)
 #define LIVES_CONTAINER(widget) GTK_CONTAINER(widget)
 #define LIVES_BIN(widget) GTK_BIN(widget)
@@ -250,12 +293,18 @@ typedef gpointer                          LiVESObjectPtr;
 #define LIVES_COMBO_BOX(widget) GTK_COMBO_BOX(widget)
 #define LIVES_BUTTON(widget) GTK_BUTTON(widget)
 #define LIVES_LABEL(widget) GTK_LABEL(widget)
+#define LIVES_ALIGNMENT(widget) GTK_ALIGNMENT(widget)
 #define LIVES_FILES_CHOOSER(widget) GTK_FILE_CHOOSER(widget)
 #define LIVES_RADIO_BUTTON(widget) GTK_RADIO_BUTTON(widget)
 #define LIVES_SPIN_BUTTON(widget) GTK_SPIN_BUTTON(widget)
+#define LIVES_TABLE(widget) GTK_TABLE(widget)
 #define LIVES_MENU(widget) GTK_MENU(widget)
+#define LIVES_MENU_ITEM(widget) GTK_MENU_ITEM(widget)
+#define LIVES_IMAGE(widget) GTK_IMAGE(widget)
 #define LIVES_IMAGE_MENU_ITEM(widget) GTK_IMAGE_MENU_ITEM(widget)
+#define LIVES_CHECK_MENU_ITEM(widget) GTK_CHECK_MENU_ITEM(widget)
 #define LIVES_FILE_CHOOSER(widget) GTK_FILE_CHOOSER(widget)
+#define LIVES_SCROLLED_WINDOW(widget) GTK_SCROLLED_WINDOW(widget)
 
 #if GTK_CHECK_VERSION(2,14,0)
 #define LIVES_SCALE_BUTTON(widget) GTK_SCALE_BUTTON(widget)
@@ -274,11 +323,18 @@ typedef gpointer                          LiVESObjectPtr;
 #define LIVES_RULER(widget) GTK_RULER(widget)
 #endif
 
+#if GTK_CHECK_VERSION(3,2,0)
+#define LIVES_GRID(widget) GTK_GRID(widget)
+#else
+#define LIVES_GRID(widget) GTK_WIDGET(widget)
+#endif
+
 #define LIVES_RANGE(widget) GTK_RANGE(widget)
 
 #define LIVES_XEVENT(event) GDK_EVENT(event)
 
 #define LIVES_IS_WIDGET(widget) GTK_IS_WIDGET(widget)
+#define LIVES_IS_WINDOW(widget) GTK_IS_WINDOW(widget)
 #if GTK_CHECK_VERSION(3,0,0)
 #define LIVES_IS_HBOX(widget) (GTK_IS_BOX(widget)&&gtk_orientable_get_orientation(GTK_ORIENTABLE(widget))==GTK_ORIENTATION_HORIZONTAL)
 #define LIVES_IS_VBOX(widget) (GTK_IS_BOX(widget)&&gtk_orientable_get_orientation(GTK_ORIENTABLE(widget))==GTK_ORIENTATION_HORIZONTAL)
@@ -288,7 +344,12 @@ typedef gpointer                          LiVESObjectPtr;
 #endif
 #define LIVES_IS_COMBO(widget) GTK_IS_COMBO_BOX(widget)
 #define LIVES_IS_BUTTON(widget) GTK_IS_BUTTON(widget)
+#define LIVES_IS_IMAGE(widget) GTK_IS_IMAGE(widget)
+#define LIVES_IS_ENTRY(widget) GTK_IS_ENTRY(widget)
+#define LIVES_IS_RANGE(widget) GTK_IS_RANGE(widget)
+#define LIVES_IS_TEXT_VIEW(widget) GTK_IS_TEXT_VIEW(widget)
 
+// (image resize) interpolation types
 #define LIVES_INTERP_BEST   GDK_INTERP_HYPER
 #define LIVES_INTERP_NORMAL GDK_INTERP_BILINEAR
 #define LIVES_INTERP_FAST   GDK_INTERP_NEAREST
@@ -457,6 +518,9 @@ typedef GdkModifierType LiVESModifierType;
 
 #endif
 
+#define LIVES_INT_TO_POINTER GINT_TO_POINTER
+#define LIVES_POINTER_TO_INT GPOINTER_TO_INT
+
 #endif
 
 
@@ -551,7 +615,7 @@ lives_painter_format_t lives_painter_image_surface_get_format(lives_painter_surf
 
 // object funcs.
 
-void lives_object_unref(LiVESObjectPtr);
+void lives_object_unref(livespointer);
 
 
 // lives_pixbuf functions
@@ -594,6 +658,8 @@ void lives_widget_set_size_request(LiVESWidget *, int width, int height);
 
 void lives_widget_reparent(LiVESWidget *, LiVESWidget *new_parent);
 
+void lives_widget_set_app_paintable(LiVESWidget *widget, boolean paintable);
+
 void lives_widget_grab_default(LiVESWidget *);
 
 LiVESWidget *lives_event_box_new(void);
@@ -622,6 +688,9 @@ boolean lives_color_parse(const char *spec, LiVESWidgetColor *);
 
 LiVESWidgetColor *lives_widget_color_copy(LiVESWidgetColor *c1orNULL, const LiVESWidgetColor *c2);
 
+LiVESWidget *lives_event_box_new(void);
+
+LiVESWidget *lives_image_new(void);
 LiVESWidget *lives_image_new_from_file(const char *filename);
 LiVESWidget *lives_image_new_from_stock(const char *stock_id, lives_icon_size_t size);
 
@@ -645,6 +714,7 @@ void lives_window_unmaximize(LiVESWindow *);
 LiVESAdjustment *lives_adjustment_new(double value, double lower, double upper, 
 						   double step_increment, double page_increment, double page_size);
 
+void lives_box_reorder_child(LiVESBox *, LiVESWidget *child, int pos);
 void lives_box_set_homogeneous(LiVESBox *, boolean homogeneous);
 void lives_box_set_spacing(LiVESBox *, int spacing);
 
@@ -669,6 +739,13 @@ LiVESWidget *lives_vpaned_new(void);
 LiVESWidget *lives_hscrollbar_new(LiVESAdjustment *);
 LiVESWidget *lives_vscrollbar_new(LiVESAdjustment *);
 
+LiVESWidget *lives_label_new(const char *text);
+
+LiVESWidget *lives_arrow_new(lives_arrow_t arrow_type, lives_shadow_t shadow_type);
+
+LiVESWidget *lives_alignment_new(float xalign, float yalign, float xscale, float yscale);
+void lives_alignment_set(LiVESAlignment *, float xalign, float yalign, float xscale, float yscale);
+
 LiVESWidget *lives_combo_new(void);
 LiVESWidget *lives_combo_new_with_model (LiVESTreeModel *);
 LiVESTreeModel *lives_combo_get_model(LiVESCombo *);
@@ -679,6 +756,7 @@ void lives_combo_set_entry_text_column(LiVESCombo *, int column);
 char *lives_combo_get_active_text(LiVESCombo *) WARN_UNUSED;
 void lives_combo_set_active_text(LiVESCombo *, const char *text);
 void lives_combo_set_active_index(LiVESCombo *, int index);
+int lives_combo_get_active(LiVESCombo *);
 boolean lives_combo_get_active_iter(LiVESCombo *, LiVESTreeIter *);
 void lives_combo_set_active_iter(LiVESCombo *, LiVESTreeIter *);
 void lives_combo_set_active_string(LiVESCombo *, const char *active_str);
@@ -768,6 +846,12 @@ void lives_entry_set_text(LiVESEntry *, const char *text);
 
 double lives_scale_button_get_value(LiVESScaleButton *);
 
+LiVESWidget *lives_grid_new(void);
+boolean lives_grid_set_row_spacing(LiVESGrid *, uint32_t spacing);
+boolean lives_grid_set_column_spacing(LiVESGrid *, uint32_t spacing);
+boolean lives_grid_attach_next_to(LiVESGrid *, LiVESWidget *child, LiVESWidget *sibling, 
+				  lives_position_t side, int width, int height);
+
 LiVESWidget *lives_menu_new(void);
 
 void lives_menu_popup(LiVESMenu *, LiVESXEventButton *);
@@ -819,6 +903,7 @@ lives_display_t lives_widget_get_display_type(LiVESWidget *);
 
 uint64_t lives_widget_get_xwinid(LiVESWidget *, const char *failure_msg);
 
+void lives_scrolled_window_set_policy(LiVESScrolledWindow *, lives_policy_t hpolicy, lives_policy_t vpolicy);
 
 // optional (return TRUE if implemented)
 
@@ -906,9 +991,10 @@ void get_border_size (LiVESWidget *win, int *bx, int *by);
 void lives_widget_set_can_focus(LiVESWidget *, boolean state);
 void lives_widget_set_can_focus_and_default(LiVESWidget *);
 
-void lives_general_button_clicked (LiVESButton *, LiVESObjectPtr data_to_free);
+void lives_general_button_clicked (LiVESButton *, livespointer data_to_free);
 
 LiVESWidget *add_hsep_to_box (LiVESBox *);
+LiVESWidget *add_vsep_to_box (LiVESBox *);
 
 LiVESWidget *add_fill_to_box (LiVESBox *);
 
